@@ -22,9 +22,9 @@ statmob<- function(x, k = 10, f = mean, ...) {
 
 
 cumstat<- function(x, f, ...) {
-  lapply(1:length(x), function(j) f(x[1:j], ...)) %>%
+  lapply(seq_along(x), function(j) f(x[1:j], ...)) %>%
     unlist %>%
-    return
+    return()
 }
 
 
